@@ -25,11 +25,30 @@
 namespace Plasma
 {
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
+static KPluginMetaData pluginMetaDatafromArg(const QVariant& arg)
+{
+    if (arg.canConvert<KPluginMetaData>()) {
+        return arg.value<KPluginMetaData>();
+    }
+
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+    return KPluginInfo(KService::serviceByStorageId(arg.toString())).toMetaData();
+QT_WARNING_POP
+}
+#endif
+
 class ContainmentActionsPrivate
 {
 public:
     ContainmentActionsPrivate(const QVariant& arg, ContainmentActions */*containmentActions*/)
-        : containmentActionsDescription(arg.canConvert<KPluginMetaData>() ? arg.value<KPluginMetaData>() : KPluginInfo(KService::serviceByStorageId(arg.toString())).toMetaData())
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
+        : containmentActionsDescription(pluginMetaDatafromArg(arg))
+#else
+        : containmentActionsDescription(arg.value<KPluginMetaData>())
+#endif
     {
     }
 
