@@ -34,11 +34,11 @@
 #include <QBuffer>
 #include <QRegularExpression>
 
-#include <kcolorscheme.h>
-#include <kconfiggroup.h>
+#include <KColorScheme>
+#include <KConfigGroup>
 #include <QDebug>
-#include <kfilterdev.h>
-#include <kiconeffect.h>
+#include <KFilterDev>
+#include <KIconEffect>
 #include <KIconLoader>
 #include <KIconTheme>
 
@@ -312,13 +312,13 @@ QPixmap SvgPrivate::findInCache(const QString &elementId, qreal ratio, const QSi
         // and store them locally.
         const QRegularExpression sizeHintedKeyExpr(QLatin1String("^") + CACHE_ID_NATURAL_SIZE(QStringLiteral("(\\d+)-(\\d+)-(.+)"), status, ratio) + QLatin1String("$"));
 
-        foreach (const QString &key, cacheAndColorsTheme()->listCachedRectKeys(path)) {
+	const auto lst = cacheAndColorsTheme()->listCachedRectKeys(path);
+        for (const QString &key : lst) {
             const auto match = sizeHintedKeyExpr.match(key);
             if (match.hasMatch()) {
                 QString baseElementId = match.captured(3);
                 QSize sizeHint(match.capturedRef(1).toInt(),
                                match.capturedRef(2).toInt());
-
                 if (sizeHint.isValid()) {
                     elementsWithSizeHints.insert(baseElementId, sizeHint);
                 }
@@ -492,7 +492,12 @@ void SvgPrivate::createRenderer()
 
 void SvgPrivate::eraseRenderer()
 {
-    if (renderer && renderer->ref.load() == 2) {
+    if (renderer &&
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        renderer->ref.loadRelaxed() == 2) {
+#else
+        renderer->ref.load() == 2) {
+#endif
         // this and the cache reference it
         s_renderers.erase(s_renderers.find(styleCrc + path));
 
@@ -558,7 +563,11 @@ QRectF SvgPrivate::findAndCacheElementRect(const QString &elementId, const QStri
 
     //This code will usually never be run because createRenderer already caches all the boundingRect in the elements in the svg
     QRectF elementRect = renderer->elementExists(elementId) ?
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+                         renderer->transformForElement(elementId).map(renderer->boundsOnElement(elementId)).boundingRect() :
+#else
                          renderer->matrixForElement(elementId).map(renderer->boundsOnElement(elementId)).boundingRect() :
+#endif
                          QRectF();
     naturalSize = renderer->defaultSize() * scaleFactor;
 
@@ -574,12 +583,6 @@ QRectF SvgPrivate::findAndCacheElementRect(const QString &elementId, const QStri
     return elementRect;
 }
 
-QMatrix SvgPrivate::matrixForElement(const QString &elementId)
-{
-    createRenderer();
-    return renderer->matrixForElement(elementId);
-}
-
 void SvgPrivate::checkColorHints()
 {
     if (elementRect(QStringLiteral("hint-apply-color-scheme")).isValid()) {
