@@ -26,10 +26,10 @@
 #include <QIcon>
 #include <QTimer>
 
-#include <kactioncollection.h>
+#include <KActionCollection>
 #include <QDebug>
-#include <kservice.h>
-#include <klocalizedstring.h>
+#include <KService>
+#include <KLocalizedString>
 #include <KConfigLoader>
 
 #include <Plasma/Plasma>
@@ -44,8 +44,6 @@
 #include <kdeclarative/configpropertymap.h>
 #include <kdeclarative/qmlobject.h>
 
-Q_DECLARE_METATYPE(AppletInterface *)
-
 AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariantList &args, QQuickItem *parent)
     : AppletQuickItem(script->applet(), parent),
       m_configuration(nullptr),
@@ -53,13 +51,16 @@ AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariant
       m_toolTipTextFormat(0),
       m_toolTipItem(nullptr),
       m_args(args),
-      m_backgroundHints(Plasma::Types::StandardBackground),
       m_hideOnDeactivate(true),
       m_oldKeyboardShortcut(0),
       m_dummyNativeInterface(nullptr),
       m_positionBeforeRemoval(QPointF(-1, -1))
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    qmlRegisterAnonymousType<QAction>("org.kde.plasma.plasmoid", 1);
+#else
     qmlRegisterType<QAction>();
+#endif
 
     connect(this, &AppletInterface::configNeedsSaving,
             applet(), &Plasma::Applet::configNeedsSaving);
@@ -93,6 +94,13 @@ AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariant
     connect(applet(), &Plasma::Applet::busyChanged,
             this, &AppletInterface::busyChanged);
 
+    connect(applet(), &Plasma::Applet::backgroundHintsChanged,
+            this, &AppletInterface::backgroundHintsChanged);
+    connect(applet(), &Plasma::Applet::effectiveBackgroundHintsChanged,
+            this, &AppletInterface::effectiveBackgroundHintsChanged);
+    connect(applet(), &Plasma::Applet::userBackgroundHintsChanged,
+            this, &AppletInterface::userBackgroundHintsChanged);
+    
     connect(applet(), &Plasma::Applet::configurationRequiredChanged, this,
             [this](bool configurationRequired, const QString &reason) {
         Q_UNUSED(configurationRequired);
@@ -125,6 +133,10 @@ AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariant
             }
         });
 
+        connect(applet()->containment()->corona(), &Plasma::Corona::availableScreenRegionChanged,
+                this, &ContainmentInterface::availableScreenRegionChanged);
+        connect(applet()->containment()->corona(), &Plasma::Corona::availableScreenRectChanged,
+                this, &ContainmentInterface::availableScreenRectChanged);
     }
 
     connect(this, &AppletInterface::expandedChanged, [=](bool expanded) {
@@ -165,11 +177,13 @@ void AppletInterface::init()
     geometryChanged(QRectF(), QRectF(x(), y(), width(), height()));
     emit busyChanged();
 
-    applet()->updateConstraints(Plasma::Types::UiReadyConstraint);
+    updateUiReadyConstraint();
 
-    connect(applet(), &Plasma::Applet::activated,
+    connect(this, &AppletInterface::isLoadingChanged, this, &AppletInterface::updateUiReadyConstraint);
+
+    connect(applet(), &Plasma::Applet::activated, this,
     [ = ]() {
-        // in case the applet doesn't want to get shrinked on reactivation,
+        // in case the applet doesn't want to get shrunk on reactivation,
         // we always expand it again (only in order to conform with legacy behaviour)
         bool activate = !( isExpanded() && isActivationTogglesExpanded() );
 
@@ -380,17 +394,27 @@ void AppletInterface::setBusy(bool busy)
 
 Plasma::Types::BackgroundHints AppletInterface::backgroundHints() const
 {
-    return m_backgroundHints;
+    return applet()->backgroundHints();
 }
 
 void AppletInterface::setBackgroundHints(Plasma::Types::BackgroundHints hint)
 {
-    if (m_backgroundHints == hint) {
-        return;
-    }
+    applet()->setBackgroundHints(hint);
+}
 
-    m_backgroundHints = hint;
-    emit backgroundHintsChanged();
+Plasma::Types::BackgroundHints AppletInterface::effectiveBackgroundHints() const
+{
+    return applet()->effectiveBackgroundHints();
+}
+
+Plasma::Types::BackgroundHints AppletInterface::userBackgroundHints() const
+{
+    return applet()->userBackgroundHints();
+}
+
+void AppletInterface::setUserBackgroundHints(Plasma::Types::BackgroundHints hint)
+{
+    applet()->setUserBackgroundHints(hint);
 }
 
 void AppletInterface::setConfigurationRequired(bool needsConfiguring, const QString &reason)
@@ -416,7 +440,7 @@ QList<QAction *> AppletInterface::contextualActions() const
         return actions;
     }
 
-    foreach (const QString &name, m_actions) {
+    for (const QString &name : qAsConst(m_actions)) {
         QAction *action = a->actions()->action(name);
 
         if (action) {
@@ -482,7 +506,8 @@ void AppletInterface::removeAction(const QString &name)
 
 void AppletInterface::clearActions()
 {
-    Q_FOREACH (const QString &action, m_actions) {
+    const auto oldActionsList = m_actions;
+    for (const QString &action : oldActionsList) {
         removeAction(action);
     }
 }
@@ -745,7 +770,7 @@ bool AppletInterface::event(QEvent *event)
         }
 
         bool keySequenceUsed = false;
-        foreach (auto a, actions) {
+        for (auto a : qAsConst(actions)) {
 
             if (a->shortcut().isEmpty()) {
                 continue;
@@ -784,6 +809,11 @@ bool AppletInterface::event(QEvent *event)
     return AppletQuickItem::event(event);
 }
 
+void AppletInterface::prepareContextualActions()
+{
+    emit applet()->contextualActionsAboutToShow();
+}
+
 bool AppletInterface::eventFilter(QObject *watched, QEvent *event)
 {
     if (event->type() == QEvent::MouseButtonPress) {
@@ -825,7 +855,7 @@ bool AppletInterface::eventFilter(QObject *watched, QEvent *event)
             if (desktopMenu->winId()) {
                 desktopMenu->windowHandle()->setTransientParent(window());
             }
-            emit applet()->contextualActionsAboutToShow();
+            prepareContextualActions();
             ci->addAppletActions(desktopMenu, applet(), event);
 
             if (!desktopMenu->isEmpty()) {
@@ -842,5 +872,16 @@ bool AppletInterface::eventFilter(QObject *watched, QEvent *event)
     return AppletQuickItem::eventFilter(watched, event);
 }
 
+void AppletInterface::updateUiReadyConstraint()
+{
+    if (!isLoading()) {
+        applet()->updateConstraints(Plasma::Types::UiReadyConstraint);
+    }
+}
+
+bool AppletInterface::isLoading() const
+{
+    return m_loading;
+}
 
 #include "moc_appletinterface.cpp"
