@@ -32,12 +32,12 @@
 #include <QScreen>
 #include <QApplication>
 
-#include <kactioncollection.h>
+#include <KActionCollection>
 #include <KAcceleratorManager>
-#include <kauthorized.h>
+#include <KAuthorized>
 #include <QDebug>
-#include <klocalizedstring.h>
-#include <kurlmimedata.h>
+#include <KLocalizedString>
+#include <KUrlMimeData>
 #include <QMimeDatabase>
 #include <KNotification>
 
@@ -459,7 +459,11 @@ void ContainmentInterface::processMimeData(QMimeData *mimeData, int x, int y, KI
 
     if (mimeData->hasFormat(QStringLiteral("text/x-plasmoidservicename"))) {
         QString data = QString::fromUtf8( mimeData->data(QStringLiteral("text/x-plasmoidservicename")) );
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        const QStringList appletNames = data.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#else
         const QStringList appletNames = data.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#endif
         for (const QString &appletName : appletNames) {
             qDebug() << "adding" << appletName;
 
