@@ -27,9 +27,9 @@
 #include <QTimer>
 #include <QWidget>
 
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <QDebug>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <Plasma/Applet>
 #include <Plasma/Corona>
@@ -63,7 +63,11 @@ DeclarativeAppletScript::DeclarativeAppletScript(QObject *parent, const QVariant
     qmlRegisterUncreatableType<WallpaperInterface>("org.kde.plasma.plasmoid", 2, 0, "Wallpaper",
             QStringLiteral("Do not create objects of type Wallpaper"));
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    qmlRegisterAnonymousType<KDeclarative::ConfigPropertyMap>("org.kde.plasma.plasmoid", 1);
+#else
     qmlRegisterType<KDeclarative::ConfigPropertyMap>();
+#endif
 }
 
 DeclarativeAppletScript::~DeclarativeAppletScript()
